@@ -1,6 +1,4 @@
 from .topic_modelling_trans import topicmodelingtransformer
 from .topic_modelling_lstm import topicmodelinglstm
 from .topic_modelling_nn import topicmodelingnn
-from .utility_module import topicmodelling
-from .eval_measure import fmeasure
-from .corpus import DocData,DocDatalstm
\ No newline at end of file
+from .utility_module import topicmodelling
\ No newline at end of file
