@@ -2,11 +2,11 @@ import tensorflow
 import torch
 import keras
 from tensorflow.keras.callbacks import LambdaCallback
-import .eval_measure
-from .corpus import DocData,DocDatalstm
-import ldann
+from topicmodeling.src.topicmodels import eval_measure
+from topicmodeling.src.topicmodels.corpus import DocData,DocDatalstm
+from topicmodeling.src.topicmodels import ldann
 from ldann import Doc2Topic,Logger,data_feeder,Doc2Topiclstm
-from .eval_measure import custom_evaluator
+from eval_measure import custom_evaluator
 import os
 import collections
 import numpy as np
@@ -42,4 +42,4 @@ def topicmodelinglstm(file_name,epochs=1,no_topic=10,topic_word=5,column_name='c
     score=totalsum
 #     totalsum/=topic_word
     finaltopics=pd.DataFrame({'topic':finaltopics})
-    return finaltopics,score
\ No newline at end of file
+    return finaltopics,score
